@@ -101,6 +101,7 @@ import aws_cdk.aws_kinesis
 import aws_cdk.aws_kinesisfirehose
 import aws_cdk.aws_kms
 import aws_cdk.aws_lambda
+import aws_cdk.aws_lambda_event_sources
 import aws_cdk.aws_s3
 import aws_cdk.aws_sns
 import aws_cdk.aws_sqs
@@ -116,7 +117,9 @@ import aws_cdk.aws_sqs
         "request_template": "requestTemplate",
         "service": "service",
         "action": "action",
+        "aws_integration_props": "awsIntegrationProps",
         "content_type": "contentType",
+        "method_options": "methodOptions",
         "path": "path",
         "request_model": "requestModel",
         "request_validator": "requestValidator",
@@ -126,16 +129,18 @@ class AddProxyMethodToApiResourceInputParams:
     def __init__(
         self,
         *,
-        api_gateway_role: aws_cdk.aws_iam.Role,
+        api_gateway_role: aws_cdk.aws_iam.IRole,
         api_method: builtins.str,
         api_resource: aws_cdk.aws_apigateway.IResource,
         request_template: builtins.str,
         service: builtins.str,
         action: typing.Optional[builtins.str] = None,
+        aws_integration_props: typing.Any = None,
         content_type: typing.Optional[builtins.str] = None,
+        method_options: typing.Optional[aws_cdk.aws_apigateway.MethodOptions] = None,
         path: typing.Optional[builtins.str] = None,
         request_model: typing.Optional[typing.Mapping[builtins.str, aws_cdk.aws_apigateway.IModel]] = None,
-        request_validator: typing.Optional[aws_cdk.aws_apigateway.RequestValidator] = None,
+        request_validator: typing.Optional[aws_cdk.aws_apigateway.IRequestValidator] = None,
     ) -> None:
         """
         :param api_gateway_role: -
@@ -144,11 +149,15 @@ class AddProxyMethodToApiResourceInputParams:
         :param request_template: -
         :param service: -
         :param action: -
+        :param aws_integration_props: -
         :param content_type: -
+        :param method_options: -
         :param path: -
         :param request_model: -
         :param request_validator: -
         """
+        if isinstance(method_options, dict):
+            method_options = aws_cdk.aws_apigateway.MethodOptions(**method_options)
         self._values: typing.Dict[str, typing.Any] = {
             "api_gateway_role": api_gateway_role,
             "api_method": api_method,
@@ -158,8 +167,12 @@ class AddProxyMethodToApiResourceInputParams:
         }
         if action is not None:
             self._values["action"] = action
+        if aws_integration_props is not None:
+            self._values["aws_integration_props"] = aws_integration_props
         if content_type is not None:
             self._values["content_type"] = content_type
+        if method_options is not None:
+            self._values["method_options"] = method_options
         if path is not None:
             self._values["path"] = path
         if request_model is not None:
@@ -168,7 +181,7 @@ class AddProxyMethodToApiResourceInputParams:
             self._values["request_validator"] = request_validator
 
     @builtins.property
-    def api_gateway_role(self) -> aws_cdk.aws_iam.Role:
+    def api_gateway_role(self) -> aws_cdk.aws_iam.IRole:
         result = self._values.get("api_gateway_role")
         assert result is not None, "Required property 'api_gateway_role' is missing"
         return result
@@ -202,11 +215,21 @@ class AddProxyMethodToApiResourceInputParams:
         result = self._values.get("action")
         return result
 
+    @builtins.property
+    def aws_integration_props(self) -> typing.Any:
+        result = self._values.get("aws_integration_props")
+        return result
+
     @builtins.property
     def content_type(self) -> typing.Optional[builtins.str]:
         result = self._values.get("content_type")
         return result
 
+    @builtins.property
+    def method_options(self) -> typing.Optional[aws_cdk.aws_apigateway.MethodOptions]:
+        result = self._values.get("method_options")
+        return result
+
     @builtins.property
     def path(self) -> typing.Optional[builtins.str]:
         result = self._values.get("path")
@@ -222,7 +245,7 @@ class AddProxyMethodToApiResourceInputParams:
     @builtins.property
     def request_validator(
         self,
-    ) -> typing.Optional[aws_cdk.aws_apigateway.RequestValidator]:
+    ) -> typing.Optional[aws_cdk.aws_apigateway.IRequestValidator]:
         result = self._values.get("request_validator")
         return result
 
@@ -242,7 +265,9 @@ class AddProxyMethodToApiResourceInputParams:
     jsii_type="@aws-solutions-constructs/core.BuildDeadLetterQueueProps",
     jsii_struct_bases=[],
     name_mapping={
-        "dead_letter_queue": "deadLetterQueue",
+        "dead_letter_queue_props": "deadLetterQueueProps",
+        "deploy_dead_letter_queue": "deployDeadLetterQueue",
+        "existing_queue_obj": "existingQueueObj",
         "max_receive_count": "maxReceiveCount",
     },
 )
@@ -250,35 +275,60 @@ class BuildDeadLetterQueueProps:
     def __init__(
         self,
         *,
-        dead_letter_queue: aws_cdk.aws_sqs.Queue,
+        dead_letter_queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
+        deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
+        existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
         max_receive_count: typing.Optional[jsii.Number] = None,
     ) -> None:
         """
-        :param dead_letter_queue: An existing queue that has already been defined to be used as the dead letter queue. Default: - Default props are used.
+        :param dead_letter_queue_props: Optional user provided properties for the dead letter queue. Default: - Default props are used
+        :param deploy_dead_letter_queue: Whether to deploy a secondary queue to be used as a dead letter queue. Default: - required field.
+        :param existing_queue_obj: Existing instance of SQS queue object, if this is set then the queueProps is ignored. Default: - None.
         :param max_receive_count: The number of times a message can be unsuccessfully dequeued before being moved to the dead letter queue. Default: - Default props are used
         """
-        self._values: typing.Dict[str, typing.Any] = {
-            "dead_letter_queue": dead_letter_queue,
-        }
+        if isinstance(dead_letter_queue_props, dict):
+            dead_letter_queue_props = aws_cdk.aws_sqs.QueueProps(**dead_letter_queue_props)
+        self._values: typing.Dict[str, typing.Any] = {}
+        if dead_letter_queue_props is not None:
+            self._values["dead_letter_queue_props"] = dead_letter_queue_props
+        if deploy_dead_letter_queue is not None:
+            self._values["deploy_dead_letter_queue"] = deploy_dead_letter_queue
+        if existing_queue_obj is not None:
+            self._values["existing_queue_obj"] = existing_queue_obj
         if max_receive_count is not None:
             self._values["max_receive_count"] = max_receive_count
 
     @builtins.property
-    def dead_letter_queue(self) -> aws_cdk.aws_sqs.Queue:
-        """An existing queue that has already been defined to be used as the dead letter queue.
+    def dead_letter_queue_props(self) -> typing.Optional[aws_cdk.aws_sqs.QueueProps]:
+        """Optional user provided properties for the dead letter queue.
 
-        default
-        :default: - Default props are used.
+        :default: - Default props are used
         """
-        result = self._values.get("dead_letter_queue")
-        assert result is not None, "Required property 'dead_letter_queue' is missing"
+        result = self._values.get("dead_letter_queue_props")
+        return result
+
+    @builtins.property
+    def deploy_dead_letter_queue(self) -> typing.Optional[builtins.bool]:
+        """Whether to deploy a secondary queue to be used as a dead letter queue.
+
+        :default: - required field.
+        """
+        result = self._values.get("deploy_dead_letter_queue")
+        return result
+
+    @builtins.property
+    def existing_queue_obj(self) -> typing.Optional[aws_cdk.aws_sqs.Queue]:
+        """Existing instance of SQS queue object, if this is set then the queueProps is ignored.
+
+        :default: - None.
+        """
+        result = self._values.get("existing_queue_obj")
         return result
 
     @builtins.property
     def max_receive_count(self) -> typing.Optional[jsii.Number]:
         """The number of times a message can be unsuccessfully dequeued before being moved to the dead letter queue.
 
-        default
         :default: - Default props are used
         """
         result = self._values.get("max_receive_count")
@@ -327,7 +377,6 @@ class BuildDynamoDBTableProps:
     def dynamo_table_props(self) -> typing.Optional[aws_cdk.aws_dynamodb.TableProps]:
         """Optional user provided props to override the default props.
 
-        default
         :default: - Default props are used
         """
         result = self._values.get("dynamo_table_props")
@@ -339,7 +388,6 @@ class BuildDynamoDBTableProps:
 
         If this is set then the dynamoTableProps is ignored
 
-        default
         :default: - None
         """
         result = self._values.get("existing_table_obj")
@@ -386,7 +434,6 @@ class BuildKinesisAnalyticsAppProps:
     def kinesis_firehose(self) -> aws_cdk.aws_kinesisfirehose.CfnDeliveryStream:
         """A Kinesis Data Firehose for the Kinesis Streams application to connect to.
 
-        default
         :default: - Default props are used
         """
         result = self._values.get("kinesis_firehose")
@@ -397,7 +444,6 @@ class BuildKinesisAnalyticsAppProps:
     def kinesis_analytics_props(self) -> typing.Any:
         """Optional user provided props to override the default props for the Kinesis analytics app.
 
-        default
         :default: - Default props are used
         """
         result = self._values.get("kinesis_analytics_props")
@@ -428,12 +474,14 @@ class BuildKinesisStreamProps:
         self,
         *,
         existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
-        kinesis_stream_props: typing.Any = None,
+        kinesis_stream_props: typing.Optional[aws_cdk.aws_kinesis.StreamProps] = None,
     ) -> None:
         """
         :param existing_stream_obj: Existing instance of Kinesis Stream, if this is set then kinesisStreamProps is ignored. Default: - None
         :param kinesis_stream_props: Optional user provided props to override the default props for the Kinesis stream. Default: - Default props are used.
         """
+        if isinstance(kinesis_stream_props, dict):
+            kinesis_stream_props = aws_cdk.aws_kinesis.StreamProps(**kinesis_stream_props)
         self._values: typing.Dict[str, typing.Any] = {}
         if existing_stream_obj is not None:
             self._values["existing_stream_obj"] = existing_stream_obj
@@ -444,17 +492,15 @@ class BuildKinesisStreamProps:
     def existing_stream_obj(self) -> typing.Optional[aws_cdk.aws_kinesis.Stream]:
         """Existing instance of Kinesis Stream, if this is set then kinesisStreamProps is ignored.
 
-        default
         :default: - None
         """
         result = self._values.get("existing_stream_obj")
         return result
 
     @builtins.property
-    def kinesis_stream_props(self) -> typing.Any:
+    def kinesis_stream_props(self) -> typing.Optional[aws_cdk.aws_kinesis.StreamProps]:
         """Optional user provided props to override the default props for the Kinesis stream.
 
-        default
         :default: - Default props are used.
         """
         result = self._values.get("kinesis_stream_props")
@@ -503,7 +549,6 @@ class BuildLambdaFunctionProps:
     def existing_lambda_obj(self) -> typing.Optional[aws_cdk.aws_lambda.Function]:
         """Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.
 
-        default
         :default: - None
         """
         result = self._values.get("existing_lambda_obj")
@@ -515,7 +560,6 @@ class BuildLambdaFunctionProps:
     ) -> typing.Optional[aws_cdk.aws_lambda.FunctionProps]:
         """User provided props to override the default props for the Lambda function.
 
-        default
         :default: - Default props are used
         """
         result = self._values.get("lambda_function_props")
@@ -588,7 +632,6 @@ class BuildQueueProps:
     def dead_letter_queue(self) -> typing.Optional[aws_cdk.aws_sqs.DeadLetterQueue]:
         """Optional dead letter queue to pass bad requests to after the max receive count is reached.
 
-        default
         :default: - Default props are used.
         """
         result = self._values.get("dead_letter_queue")
@@ -603,7 +646,6 @@ class BuildQueueProps:
         If importing an encryption key, it must be specified in
         the encryptionKey property for this construct.
 
-        default
         :default: - false (encryption enabled with AWS Managed KMS Key).
         """
         result = self._values.get("enable_encryption_with_customer_managed_key")
@@ -613,7 +655,6 @@ class BuildQueueProps:
     def encryption_key(self) -> typing.Optional[aws_cdk.aws_kms.Key]:
         """An optional, imported encryption key to encrypt the SQS queue with.
 
-        default
         :default: - not specified.
         """
         result = self._values.get("encryption_key")
@@ -623,7 +664,6 @@ class BuildQueueProps:
     def encryption_key_props(self) -> typing.Optional[aws_cdk.aws_kms.KeyProps]:
         """Optional user-provided props to override the default props for the encryption key.
 
-        default
         :default: - Ignored if encryptionKey is provided
         """
         result = self._values.get("encryption_key_props")
@@ -633,7 +673,6 @@ class BuildQueueProps:
     def existing_queue_obj(self) -> typing.Optional[aws_cdk.aws_sqs.Queue]:
         """Existing instance of SQS queue object, if this is set then the queueProps is ignored.
 
-        default
         :default: - None.
         """
         result = self._values.get("existing_queue_obj")
@@ -643,7 +682,6 @@ class BuildQueueProps:
     def queue_props(self) -> typing.Optional[aws_cdk.aws_sqs.QueueProps]:
         """Optional user provided props to override the default props for the primary queue.
 
-        default
         :default: - Default props are used.
         """
         result = self._values.get("queue_props")
@@ -685,7 +723,6 @@ class BuildS3BucketProps:
     def bucket_props(self) -> typing.Optional[aws_cdk.aws_s3.BucketProps]:
         """User provided props to override the default props for the S3 Bucket.
 
-        default
         :default: - Default props are used
         """
         result = self._values.get("bucket_props")
@@ -756,7 +793,6 @@ class BuildTopicProps:
         If importing an encryption key, it must be specified in
         the encryptionKey property for this construct.
 
-        default
         :default: - false (encryption enabled with AWS Managed KMS Key).
         """
         result = self._values.get("enable_encryption_with_customer_managed_key")
@@ -766,7 +802,6 @@ class BuildTopicProps:
     def encryption_key(self) -> typing.Optional[aws_cdk.aws_kms.Key]:
         """An optional, imported encryption key to encrypt the SNS topic with.
 
-        default
         :default: - not specified.
         """
         result = self._values.get("encryption_key")
@@ -776,7 +811,6 @@ class BuildTopicProps:
     def encryption_key_props(self) -> typing.Optional[aws_cdk.aws_kms.KeyProps]:
         """Optional user-provided props to override the default props for the encryption key.
 
-        default
         :default: - Ignored if encryptionKey is provided
         """
         result = self._values.get("encryption_key_props")
@@ -786,7 +820,6 @@ class BuildTopicProps:
     def existing_topic_obj(self) -> typing.Optional[aws_cdk.aws_sns.Topic]:
         """Existing instance of SNS Topic object, if this is set then the TopicProps is ignored.
 
-        default
         :default: - None.
         """
         result = self._values.get("existing_topic_obj")
@@ -796,7 +829,6 @@ class BuildTopicProps:
     def topic_props(self) -> typing.Optional[aws_cdk.aws_sns.TopicProps]:
         """Optional user provided props to override the default props for the SNS topic.
 
-        default
         :default: - Default props are used.
         """
         result = self._values.get("topic_props")
@@ -940,6 +972,69 @@ class CognitoOptions:
         )
 
 
+@jsii.data_type(
+    jsii_type="@aws-solutions-constructs/core.EventSourceProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "deploy_sqs_dlq_queue": "deploySqsDlqQueue",
+        "event_source_props": "eventSourceProps",
+        "sqs_dlq_queue_props": "sqsDlqQueueProps",
+    },
+)
+class EventSourceProps:
+    def __init__(
+        self,
+        *,
+        deploy_sqs_dlq_queue: typing.Optional[builtins.bool] = None,
+        event_source_props: typing.Optional[aws_cdk.aws_lambda_event_sources.StreamEventSourceProps] = None,
+        sqs_dlq_queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
+    ) -> None:
+        """
+        :param deploy_sqs_dlq_queue: -
+        :param event_source_props: -
+        :param sqs_dlq_queue_props: -
+        """
+        if isinstance(event_source_props, dict):
+            event_source_props = aws_cdk.aws_lambda_event_sources.StreamEventSourceProps(**event_source_props)
+        if isinstance(sqs_dlq_queue_props, dict):
+            sqs_dlq_queue_props = aws_cdk.aws_sqs.QueueProps(**sqs_dlq_queue_props)
+        self._values: typing.Dict[str, typing.Any] = {}
+        if deploy_sqs_dlq_queue is not None:
+            self._values["deploy_sqs_dlq_queue"] = deploy_sqs_dlq_queue
+        if event_source_props is not None:
+            self._values["event_source_props"] = event_source_props
+        if sqs_dlq_queue_props is not None:
+            self._values["sqs_dlq_queue_props"] = sqs_dlq_queue_props
+
+    @builtins.property
+    def deploy_sqs_dlq_queue(self) -> typing.Optional[builtins.bool]:
+        result = self._values.get("deploy_sqs_dlq_queue")
+        return result
+
+    @builtins.property
+    def event_source_props(
+        self,
+    ) -> typing.Optional[aws_cdk.aws_lambda_event_sources.StreamEventSourceProps]:
+        result = self._values.get("event_source_props")
+        return result
+
+    @builtins.property
+    def sqs_dlq_queue_props(self) -> typing.Optional[aws_cdk.aws_sqs.QueueProps]:
+        result = self._values.get("sqs_dlq_queue_props")
+        return result
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "EventSourceProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
 __all__ = [
     "AddProxyMethodToApiResourceInputParams",
     "BuildDeadLetterQueueProps",
@@ -952,6 +1047,7 @@ __all__ = [
     "BuildTopicProps",
     "CfnDomainOptions",
     "CognitoOptions",
+    "EventSourceProps",
 ]
 
 publication.publish()
